Rename statement actions (from Parse-prefix to ActOn-prefix).


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@42000 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/Sema/SemaExprCXX.cpp b/Sema/SemaExprCXX.cpp
index be1d551..0e3c968 100644
--- a/Sema/SemaExprCXX.cpp
+++ b/Sema/SemaExprCXX.cpp
@@ -16,9 +16,9 @@
 #include "clang/AST/ASTContext.h"
 using namespace clang;
 
-/// ParseCXXCasts - Parse {dynamic,static,reinterpret,const}_cast's.
+/// ActOnCXXCasts - Parse {dynamic,static,reinterpret,const}_cast's.
 Action::ExprResult
-Sema::ParseCXXCasts(SourceLocation OpLoc, tok::TokenKind Kind,
+Sema::ActOnCXXCasts(SourceLocation OpLoc, tok::TokenKind Kind,
                     SourceLocation LAngleBracketLoc, TypeTy *Ty,
                     SourceLocation RAngleBracketLoc,
                     SourceLocation LParenLoc, ExprTy *E,
@@ -36,9 +36,9 @@
   return new CXXCastExpr(Op, QualType::getFromOpaquePtr(Ty), (Expr*)E, OpLoc);
 }
 
 /// ParseCXXBoolLiteral - Parse {true,false} literals.
 Action::ExprResult
-Sema::ParseCXXBoolLiteral(SourceLocation OpLoc, tok::TokenKind Kind) {
+Sema::ActOnCXXBoolLiteral(SourceLocation OpLoc, tok::TokenKind Kind) {
   assert((Kind != tok::kw_true || Kind != tok::kw_false) &&
          "Unknown C++ Boolean value!");
   return new CXXBoolLiteralExpr(Kind == tok::kw_true, Context.BoolTy, OpLoc);
@@ -36,9 +36,9 @@
 }
 
-/// ParseCXXBoolLiteral - Parse {true,false} literals.
+/// ActOnCXXBoolLiteral - Parse {true,false} literals.
 Action::ExprResult